package com.ruoyi.common.core.domain;

import com.baomidou.mybatisplus.annotation.FieldFill;
import com.baomidou.mybatisplus.annotation.TableField;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.ruoyi.common.core.page.ReqDomain;
import com.ruoyi.common.utils.StringUtils;
import io.swagger.annotations.ApiModelProperty;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;
import lombok.experimental.SuperBuilder;

import java.io.Serializable;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;

/**
 * Entity基类
 *
 * @author ruoyi
 */
@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
public class BaseEntity implements Serializable {
    private static final long serialVersionUID = 1L;

    /**
     * 搜索值
     */
    @JsonIgnore
    @TableField(exist = false)
    private String searchValue;

    /**
     * 创建者
     */
    @TableField(value = "create_by" , fill = FieldFill.INSERT)
    @ApiModelProperty(hidden=true)
    private Long createBy;

    /**
     * 创建时间
     */
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @TableField(value = "create_time" , fill = FieldFill.INSERT)
    @ApiModelProperty(hidden=true)
    private Date createTime;

    /**
     * 更新者
     */
    @TableField(value = "update_by" , fill = FieldFill.UPDATE)
    @ApiModelProperty(hidden=true)
    private Long updateBy;

    /**
     * 更新时间
     */
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @TableField(value = "update_time" , fill = FieldFill.UPDATE)
    @ApiModelProperty(hidden=true)
    private Date updateTime;

    /**
     * 请求参数
     */
    @JsonInclude(JsonInclude.Include.NON_EMPTY)
    @TableField(exist = false)
    @ApiModelProperty(hidden=true)
    private Map<String, Object> params;

    public Map<String, Object> getParams () {
        if (params == null) {
            params = new HashMap<>();
        }
        return params;
    }

    public void setParams (Map<String, Object> params) {
        this.params = params;
    }

    /**
     * 开始时间
     * @param key 属性名称
     * @return 结果数据
     */
    public Object getBeginParam(String key){
        return getParams().get(
                StringUtils.format(ReqDomain.BEGIN_REF, key)
        );
    }

    /**
     * 开始时间
     * @param key 属性名称
     * @return 结果数据
     */
    public Object getEndParam(String key){
        return getParams().get(
                StringUtils.format(ReqDomain.END_REF, key)
        );
    }

    /**
     * 获取区间数据
     * @param key 属性名称
     * @return 结果数据
     */
    public Object[] getBetween(String key){
        return new Object[]{getBeginParam(key), getEndParam(key)};
    }
}
